// Copyright 2004 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.
import java.io.*;
import javax.microedition.io.*;
import javax.microedition.io.file.*;
import javax.microedition.lcdui.*;

// This class displays a selected image centered in the screen
class ImageCanvas
  extends Canvas
{
  private final ImageViewerMIDlet midlet;
  private static final int CHUNK_SIZE = 1024;
  private Image currentImage = null;


  ImageCanvas(ImageViewerMIDlet midlet)
  {
    this.midlet = midlet;
  }


  public void displayImage(String imgName)
  {
    try
    {
      FileConnection fileConn =
        (FileConnection)Connector.open(imgName, Connector.READ);
      // load the image data in memory
      // Read data in CHUNK_SIZE chunks
      InputStream fis = fileConn.openInputStream();
      long overallSize = fileConn.fileSize();

      int length = 0;
      byte[] imageData = new byte[0];
      while (length < overallSize)
      {
        byte[] data = new byte[CHUNK_SIZE];
        int readAmount = fis.read(data, 0, CHUNK_SIZE);
        byte[] newImageData = new byte[imageData.length + CHUNK_SIZE];
        System.arraycopy(imageData, 0, newImageData, 0, length);
        System.arraycopy(data, 0, newImageData, length, readAmount);
        imageData = newImageData;
        length += readAmount;
      }

      fis.close();
      fileConn.close();
      currentImage = Image.createImage(imageData, 0, length);
      repaint();
    }
    catch (IOException e)
    {
      midlet.showError(e);
    }
    catch (Exception e)
    {
      e.printStackTrace();
      midlet.showError(e);
    }

  }


  protected void paint(Graphics g)
  {
    int w = getWidth();
    int h = getHeight();

    // Set background color to black
    g.setColor(0x00000000);
    g.fillRect(0, 0, w, h);

    if (currentImage != null)
    {
      g.drawImage(currentImage,
        w / 2,
        h / 2,
        Graphics.HCENTER | Graphics.VCENTER);
    }
    else
    {
      // If no image is available display a message
      g.setColor(0x00FFFFFF);
      g.drawString("No image",
        w / 2,
        h / 2,
        Graphics.HCENTER | Graphics.BASELINE);
    }
  }


  protected void keyReleased(int keyCode)
  {
    // Exit with any key
    midlet.displayFileBrowser();
  }
}

