// Copyright 2004 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.
import javax.microedition.lcdui.*;
import javax.microedition.midlet.*;

// Main class which inits the connection and create the screens
public class ImageViewerMIDlet
   extends MIDlet
{
  private final Image logo;
  private final ImageCanvas imageCanvas;
  private FileSelector fileSelector;
  private final InputScreen inputScreen;
  private int operationCode = -1;


  public ImageViewerMIDlet()
  {
    // init basic parameters
    logo = makeImage("/logo.png");
    ErrorScreen.init(logo, Display.getDisplay(this));
    imageCanvas = new ImageCanvas(this);
    fileSelector = new FileSelector(this);
    inputScreen = new InputScreen(this);
  }


  public void startApp()
  {
    Displayable current = Display.getDisplay(this).getCurrent();

    if (current == null)
    {
      // Checks whether the API is available
      boolean isAPIAvailable = System.getProperty(
        "microedition.io.file.FileConnection.version") != null;
      // shows splash screen
      String text = getAppProperty("MIDlet-Name") + "\n" +
        getAppProperty("MIDlet-Vendor")+ System.getProperty("fileconn.dir.photos");
      if (!isAPIAvailable)
      {
        text += "\nFile Connection API is not available";
      }
      Alert splashScreen = new Alert(null,
        text,
        logo,
        AlertType.INFO);
      if (isAPIAvailable)
      {
        splashScreen.setTimeout(30);
        Display.getDisplay(this).setCurrent(
          splashScreen, fileSelector);
      }
      else
      {
        Display.getDisplay(this).setCurrent(splashScreen);
      }
    }
    else
    {
      Display.getDisplay(this).setCurrent(current);
    }
  }


  public void pauseApp()
  {
  }


  public void destroyApp(boolean unconditional)
  {
    // stop the commands queue thread
    fileSelector.stop();
    notifyDestroyed();
  }


  void fileSelectorExit()
  {
    destroyApp(false);
  }


  void cancelInput()
  {
    Display.getDisplay(this).setCurrent(fileSelector);
  }


  void input(String input)
  {
    fileSelector.inputReceived(input, operationCode);
    Display.getDisplay(this).setCurrent(fileSelector);
  }


  void displayImage(String imageName)
  {
    imageCanvas.displayImage(imageName);
    Display.getDisplay(this).setCurrent(imageCanvas);
  }


  void displayFileBrowser()
  {
    Display.getDisplay(this).setCurrent(fileSelector);
  }


  void showError(Exception e)
  {
    ErrorScreen.showError(e.getMessage(), fileSelector);
  }


  void showMsg(String text)
  {
    Alert infoScreen = new Alert(null,
      text,
      logo,
      AlertType.INFO);
    infoScreen.setTimeout(3000);
    Display.getDisplay(this).setCurrent(infoScreen, fileSelector);
  }


  void requestInput(String text, String label, int operationCode)
  {
    inputScreen.setQuestion(text, label);
    this.operationCode = operationCode;
    Display.getDisplay(this).setCurrent(inputScreen);
  }


  // loads a given image by name
  static Image makeImage(String filename)
  {
    Image image = null;

    try
    {
      image = Image.createImage(filename);
    }
    catch (Exception e)
    {
      // use a null image instead
    }

    return image;
  }

}

